@@ -40,7 +40,7 @@ test_that("read Quick TUV", {
   expect_equal(format(getWhenMeasured(qtuv.spct)),
                format(ymd("2015-06-30")))
   expect_true(all(is.na(getWhereMeasured(qtuv.spct))))
-  expect_named(getWhereMeasured(qtuv.spct), c("lon", "lat"))
+  expect_named(getWhereMeasured(qtuv.spct), c("lon", "lat", "address"))
   expect_equal(getWhatMeasured(qtuv.spct), 
                "Quick TUV spectral simulation File: qtuv.txt")
   expect_equal(getTimeUnit(qtuv.spct), "second")
@@ -80,7 +80,8 @@ test_that("read Quick TUV", {
   expect_equal(getWhenMeasured(qtuv_long.spct),
                ymd_hms("2018-08-01 12:00:00", tz = "UTC"))
   expect_equal(getWhereMeasured(qtuv_long.spct), 
-               data.frame(lon = -15, lat = 60))
+               data.frame(lon = -15, lat = 60, address = NA_character_,
+                          stringsAsFactors = FALSE))
   expect_equal(getWhatMeasured(qtuv_long.spct), 
                "Quick TUV spectral simulation File: qtuv-long.txt")
   expect_equal(getTimeUnit(qtuv_long.spct), "second")
@@ -102,7 +103,7 @@ test_that("read Quick TUV", {
   expect_named(qtuv_empty.spct, c("w.length", "s.e.irrad"))
   expect_true(all(is.na(getWhenMeasured(qtuv_empty.spct))))
   expect_true(all(is.na(getWhereMeasured(qtuv_empty.spct))))
-  expect_named(getWhereMeasured(qtuv_empty.spct), c("lon", "lat"))
+  expect_named(getWhereMeasured(qtuv_empty.spct), c("lon", "lat", "address"))
   expect_true(is.na(getWhatMeasured(qtuv_empty.spct)))
   expect_equal(getTimeUnit(qtuv_empty.spct), "second")
   expect_equal(length(comment(qtuv_empty.spct)), 0L)
@@ -139,8 +140,10 @@ test_that("read Quick TUV", {
   )
   expect_equal(getWhenMeasured(qtuv_spct_summ.spct),
                ymd_hms("2015-06-30 12:00:00"))
-  expect_true(all(getWhereMeasured(qtuv_spct_summ.spct) == 0))
-  expect_named(getWhereMeasured(qtuv_spct_summ.spct), c("lon", "lat"))
+  expect_equal(getWhereMeasured(qtuv_spct_summ.spct),
+                    data.frame(lon = 0.0, lat = 0.0, address = NA_character_, 
+                               stringsAsFactors = FALSE))
+  expect_named(getWhereMeasured(qtuv_spct_summ.spct), c("lon", "lat", "address"))
   expect_equal(getWhatMeasured(qtuv_spct_summ.spct), 
                "Quick TUV spectral simulation File: qtuv-spct-and-summaries.txt")
   expect_equal(getTimeUnit(qtuv_spct_summ.spct), "second")
@@ -209,7 +212,8 @@ test_that("read TUV", {
                                "angle", "date"))
   expect_equal(length(getWhenMeasured(usrout.spct)), 8L)
   expect_equal(getWhereMeasured(usrout.spct), 
-               data.frame(lon = -15, lat = 60))
+               data.frame(lon = -15, lat = 60, address = NA_character_,
+                          stringsAsFactors = FALSE))
   expect_equal(getWhatMeasured(usrout.spct), "TUV spectral simulation File: usrout.txt")
   expect_equal(length(comment(usrout.spct)), 1L)
   
@@ -219,7 +223,7 @@ test_that("read TUV", {
                                  tz = "UTC")
   
   expect_true(all(is.na(getWhereMeasured(usrouta.spct))))
-  expect_named(getWhereMeasured(usrouta.spct), c("lon", "lat"))
+  expect_named(getWhereMeasured(usrouta.spct), c("lon", "lat", "address"))
   
   skip_on_cran()
   file.name <- 
@@ -245,7 +249,8 @@ test_that("read TUV", {
                               "angle", "date"))
   expect_equal(length(getWhenMeasured(usrout2.spct)), 13L)
   expect_equal(getWhereMeasured(usrout2.spct), 
-               data.frame(lon = -15, lat = 60))
+               data.frame(lon = -15, lat = 60, address = NA_character_,
+                          stringsAsFactors = FALSE))
   expect_equal(getWhatMeasured(usrout2.spct), "TUV spectral simulation File: usrout2.txt")
   expect_equal(length(comment(usrout.spct)), 1L)
 })
@@ -279,7 +284,8 @@ test_that("read TUV to mspct", {
   # bug un subset2mspct()
   # expect_equal(length(getWhenMeasured(usrout.mspct[[1]])), 1L)
   expect_equal(getWhereMeasured(usrout.mspct[[1]]), 
-               data.frame(lon = -15, lat = 60))
+               data.frame(lon = -15, lat = 60, address = NA_character_,
+                          stringsAsFactors = FALSE))
   expect_equal(getWhatMeasured(usrout.mspct[[1]]), "TUV spectral simulation File: usrout.txt")
   expect_equal(length(comment(usrout.mspct[[1]])), 1L)
   expect_equal(length(comment(usrout.mspct)), 0L)
@@ -290,7 +296,7 @@ test_that("read TUV to mspct", {
                                         tz = "UTC")
   
   expect_true(all(is.na(getWhereMeasured(usrouta.mspct[[1]]))))
-  expect_named(getWhereMeasured(usrouta.mspct[[1]]), c("lon", "lat"))
+  expect_named(getWhereMeasured(usrouta.mspct[[1]]), c("lon", "lat", "address"))
   
   file.name <- 
     system.file("extdata", "usrout2.txt", 
@@ -319,7 +325,8 @@ test_that("read TUV to mspct", {
   # bug un subset2mspct()
   # expect_equal(length(getWhenMeasured(usrout2.mspct[[1]])), 1L)
   expect_equal(getWhereMeasured(usrout2.mspct[[1]]), 
-               data.frame(lon = -15, lat = 60))
+               data.frame(lon = -15, lat = 60, address = NA_character_,
+                          stringsAsFactors = FALSE))
   expect_equal(getWhatMeasured(usrout2.mspct[[1]]),
                "TUV spectral simulation File: usrout2.txt")
   expect_equal(length(comment(usrout2.mspct[[1]])), 1L)
